pub struct RuntimeHookChain { /* private fields */ }Expand description
Ordered runtime hook composition.
Lifecycle, progress, telemetry, and log events are sent to every hook. Transform hooks are applied in order, with each hook receiving the payload returned by the previous hook.
Implementations
Sourceimpl RuntimeHookChain
impl RuntimeHookChain
Sourcepub fn new(hooks: Vec<Arc<dyn RuntimeHooks>>) -> Self
pub fn new(hooks: Vec<Arc<dyn RuntimeHooks>>) -> Self
Creates a chain from hooks in invocation order.